@@ -16,12 +16,12 @@
 %%
 %%  xb           vector of x-coodinates
 %%  yb           vector of y-coodinates
-% written by Stefan Mueller stefan.mueller@fgan.de 2001
+% written by Stefan Mueller stefan.mueller@fgan.de (C) 2003
 
 function [xb,yb]=ebar(y,barWidth,barNumber,clusterSize,x)
   eglobpar
   if nargin>5 | nargin<1 | nargin==3
-    usage('[xb yb]=ebar(y[,barWidth[,barNumber,clusterSize[,x]])');
+    eusage('[xb yb]=ebar(y[,barWidth[,barNumber,clusterSize[,x]])');
   end
   n=length(y);
   m=1:n;
