@@ -7,16 +7,20 @@ delta=10*pi/(n-1);
 x=-5*pi:delta:5*pi;
 [a b]=meshgrid(x,x);
 R=sqrt(a.^2+b.^2) + eps;
-matrix=sin(R)./R;
+matrix=100*(sin(R)./R+0.3);
 
 % scaled shadow image
 ePlotAreaPos=[30 140];
 ePlotAreaHeight=80;
 ePlotAreaWidth=80;
 ePlotTitleDistance=15;
+eImageLegendScaleType=2;
 ePlotTitleText='Scaled Shadow Image';
 colorMap=[1 1 0;1 0 0;0 1 0;0 0 1;1 0 1];
 eshadois(matrix,colorMap,'e');
+etext('        (log scale)',eImageLegendValuePos(1,1),...
+  eImageLegendValuePos(1,2),4,4,1);
+
 
 % shadow image
 ePlotAreaPos=[10 30];
