@@ -12,11 +12,11 @@
 %%  dx          delta x 
 %%  dy          delta y 
 %%
-% written by Stefan Mueller stefan.mueller@fgan.de 2002
+% written by Stefan Mueller stefan.mueller@fgan.de (C) 2003
 
 function [px,py] = egradient(z,dx,dy)
   if nargin > 3
-    usage ('[px py]=egradient(z[,dx[,dy]])');
+    eusage('[px py]=egradient(z[,dx[,dy]])');
   end
   if nargin < 3
     dy = dx;
