@@ -5,9 +5,15 @@
 %%  eimage(matrix[,colorMap])
 %%
 %%PARAMETER(S)
-%%  matrix     matrix for image 
-%%             each value of the matrix is a row index of the colormap
+%%  matrix     rows x cols matrix for image 
+%%               if colorMap=-1 then
+%%                  image is filled with RGB values
+%%                  value=R*2^16+G*2^8+B) and R,G,B are integer of 0:255
+%%                else
+%%                  matrix is filled with indices of colormap  
+%%             or a string of filename of a JPEG-file
 %%  colorMap   define own colormap  
+%%             default:colorMap=ecolors(eImageDefaultColorMap)
 %% 
 %%GLOBAL PARAMETER(S)
 %%  eImageDefaultColorMap 
@@ -16,19 +22,19 @@
 %%  ePlotAreaHeight
 %%  eImageFrameVisible
 %%  eAxesLineWidth
-% written by Stefan Mueller stefan.mueller@fgan.de 1997
+% written by Stefan Mueller stefan.mueller@fgan.de (C) 2003
 
-function x=eimage(matrix,colorMap)
+function eimage(matrix,colorMap)
   if  nargin >2
-    usage('eimage(matrix[,colorMap])');
+    eusage('eimage(matrix[,colorMap])');
   end
   eglobpar;
   if nargin<2
     colorMap=ecolors(eImageDefaultColorMap); 
   end
   if nargin<1
-    [matrix colorMap]=eppmread([ePath 'default.ppm']);
-    x=matrix;
+    matrix=eppmread;
+    colorMap=-1;
   end
   % write title
   etitle;
@@ -38,5 +44,5 @@ function x=eimage(matrix,colorMap)
   if eImageFrameVisible
     erect(eFile,ePlotAreaPos(1)*eFac,ePlotAreaPos(2)*eFac,...
           ePlotAreaWidth*eFac,ePlotAreaHeight*eFac,...
-          eAxesLineWidth*eFac,[0 0 0],0);
+          eAxesLineWidth*eFac,[0 0 0],0,0);
   end
