@@ -10,11 +10,11 @@
 %%  epsFileName   name of eps-file 
 %%  scaleX        scale factor in x-direction
 %%  scaleY        scale factor in y-direction
-% written by Stefan Mueller stefan.mueller@fgan.de 1999
+% written by Stefan Mueller stefan.mueller@fgan.de (C) 2003
 
 function einseps(xPos,yPos,epsFileName,scaleX,scaleY,rotation)
   if nargin<3 | nargin>6
-    usage('einseps(xPos,yPos,epsFileName,[,scaleX[,scaleY[,rotation]]])');
+    eusage('einseps(xPos,yPos,epsFileName,[,scaleX[,scaleY[,rotation]]])');
   end
   if nargin<6
     rotation=0;
