@@ -7,30 +7,33 @@
 %%PARAMETER(S)
 %%  xData       matrix(2xn) of x0,x1-data of lines
 %%  yData       matrix(2xn) of y0,y1-data of lines
-%%  lineWidth   width of polyline 
+%%  lineWidth   width of lines 
+%%              default: lineWidth=eLineWidth
 %%  dash        if dash=0 then draw solid lines
 %%              else value of dash is the distance of dashes 
-%%  color       vector of polyline color ([r g b])
+%%              default: dash=eLineDash
+%%  color       vector of line color ([r g b])
+%%              default: color=eLineColor
 %% 
 %%GLOBAL PARAMETER(S)
-%%  eLineColor
-%%  eLineDash
 %%  eLineWidth
-% written by Stefan Mueller stefan.mueller@fgan.de 1999
+%%  eLineDash
+%%  eLineColor
+% written by Stefan Mueller stefan.mueller@fgan.de (C) 2003
 
 function elines (xData,yData,lineWidth,dash,color)
   if nargin<2 | nargin>5
-    usage ('elines (xData,yData,[,lineWidth[,dash[,color]]])');
+    eusage('elines(xData,yData,[,lineWidth[,dash[,color]]])');
   end
   eglobpar;
-  if nargin==5
-    eLineColor=color;
+  if nargin<5
+    color=eLineColor;
   end
-  if nargin>3
-    eLineDash=dash;
+  if nargin<4
+    dash=eLineDash;
   end
-  if nargin>2
-    eLineWidth=lineWidth;
+  if nargin<3
+    lineWidth=eLineWidth;
   end
   [xr xc]=size(xData);
   if xr>2
@@ -45,4 +48,4 @@ function elines (xData,yData,lineWidth,dash,color)
   end
   yData=reshape(yData,1,2*yc);
     exyline(eFile,0,0,xData*eFac,yData*eFac,...
-            eLineColor,eLineDash*eFac,eLineWidth*eFac);
+            color,dash*eFac,lineWidth*eFac);
