@@ -17,11 +17,11 @@
 %%  eParamTextFont
 %%  eParamValueFont
 %%  eParamLineDistance
-% written by Stefan Mueller stefan.mueller@fgan.de 1997
+% written by Stefan Mueller stefan.mueller@fgan.de (C) 2003
 
 function eparam(text1,text2,x,y)
   if nargin~=2 & nargin~=4 
-    usage('eparam(text1,text2[,x,y])');
+    eusage('eparam(text1,text2[,x,y])');
   end
   eglobpar;
   if nargin<4 
@@ -34,11 +34,8 @@ function eparam(text1,text2,x,y)
   lineDistance=eParamLineDistance/100*eParamFontSize;
   valueDistance=eParamTextValueDistance/20*eParamFontSize;
   valueOffset=eParamFontSize; 
-
-  etext(text1,x,y,...
-        eParamFontSize,1,eParamTextFont,0); 
-  etext(':',x+valueDistance-valueOffset,y,...
-        eParamFontSize,1,eParamTextFont,0); 
-  etext(text2,x+valueDistance,y,...
-        eParamFontSize,1,eParamValueFont,0); 
+  [xw yh]=etabdef(1,3,x,y,2*valueDistance,eParamFontSize,[10 1 10]);
+  etabtext(xw,yh,1,1,text1,-1,eParamTextFont);
+  etabtext(xw,yh,1,2,':',0,eParamTextFont);
+  etabtext(xw,yh,1,3,text2,1,eParamValueFont);
   eParamPos(2)=eParamPos(2)-lineDistance;
