@@ -2,7 +2,7 @@
 %%  eplo2win - transform coordinates , plotarea to window 
 %%
 %%SYNOPSIS
-%%  [winX winY]=eplo2win(x,y)
+%%  [winX winY]=eplo2win(ploX,plotY)
 %%
 %%PARAMETER(S)
 %%  ploX     x-vector of coordinates of plotarea
@@ -11,13 +11,19 @@
 %%  winY     y-vector of coordinates of window
 %% 
 %%GLOBAL PARAMETER(S)
-% written by Stefan Mueller stefan.mueller@fgan.de 1998
+% written by Stefan Mueller stefan.mueller@fgan.de (C) 2003
 
 function [winX,winY]=eplo2win(ploX,ploY)
   if nargin~=2
-    usage ('[winX winY]=eplo2win(ploX,ploY)');
+    eusage('[winX winY]=eplo2win(ploX,ploY)');
   end
   eglobpar;
+  if  eXAxisSouthScaleType==2
+    ploX=log10(ploX);
+  end
+  if  eYAxisWestScaleType==2
+    ploY=log10(ploY);
+  end
   xFac=ePlotAreaWidth/...
       (ePlotAreaXValueEnd-ePlotAreaXValueStart);
   yFac=ePlotAreaHeight/...
