@@ -16,21 +16,21 @@
 %%  ePlotTitleTextFont
 %%  ePolarPlotAreaCenterPos
 %%  ePolarPlotAreaRadMax
-% written by Stefan Mueller stefan.mueller@fgan.de 2002
+% written by Stefan Mueller stefan.mueller@fgan.de (C) 2003
 
 function eptitle(text,distance,fontSize)
   if  nargin >3
-    usage('eptitle([text[,distance[,fontSize]]])');
+    eusage('eptitle([text[,distance[,fontSize]]])');
   end
   eglobpar;
-  if nargin>0
-    ePlotTitleText=text;
+  if nargin<3
+    fontSize=ePlotTitleFontSize;
   end
-  if nargin>1
-    ePlotTitleDistance=distance;
+  if nargin<2
+    distance=ePlotTitleDistance;
   end
-  if nargin>2
-    ePlotTitleFontSize=fontSize;
+  if nargin<1
+    text=ePlotTitleText;
   end
   if strcmp(ePlotTitleText,'')~=1
     etext(ePlotTitleText,ePolarPlotAreaCenterPos(1),...
