@@ -1,9 +1,9 @@
 % newFont=erencode( epsFile ,oldFont)
-% written by Stefan Mueller stefan.mueller@fgan.de 1997
+% written by Stefan Mueller stefan.mueller@fgan.de (C) 2003
 
 function newFont=erencode(epsFile,oldFont)
   if (nargin~=2)
-    usage ('newFont=erencode ( epsFile ,oldFont)');
+    eusage('newFont=erencode(epsFile,oldFont)');
   end
   blaStr='                                                 ';
   oldSize=length(oldFont);
