@@ -2,7 +2,7 @@
 %%  eshadoi  - draw shadow image of a matrix 
 %%
 %%SYNOPSIS
-%%  [x colorMapNew]=eshadoi(matrix[,colorMap])
+%%  [x,colorMapNew]=eshadoi(matrix[,colorMap])
 %%
 %%PARAMETER(S)
 %%  matrix             matrix for image 
@@ -15,11 +15,11 @@
 %%
 %%GLOBAL PARAMETER(S)
 %%  eImageDefaultColorMap
-% written by Stefan Mueller stefan.mueller@fgan.de 1998
+% written by Stefan Mueller stefan.mueller@fgan.de (C) 2003
 
 function [x,colorMapNew]=eshadoi(matrix,colorMap)
   if nargin >2
-    usage('[x colorMapNew]=eshadoi(matrix[,coloMap])');
+    eusage('[x,colorMapNew]=eshadoi(matrix[,coloMap])');
   end
   eglobpar;
   if nargin==0
