@@ -14,11 +14,11 @@
 %%  x                  mix shadow image matrix
 %%  colorMapNew        colormap of x
 %%
-% written by Stefan Mueller stefan.mueller@fgan.de 2000
+% written by Stefan Mueller stefan.mueller@fgan.de (C) 2003
 
 function [x,colorMapNew]=eshadoix(matrix,coverImg,colorMap)
   if nargin ~= 3
-    usage('[x colorMapNew]=eshadoix(matrix,coverImg,coloMap)');
+    eusage('[x colorMapNew]=eshadoix(matrix,coverImg,coloMap)');
   end
   eglobpar;
   if sum(2*colorMap(:,1)-colorMap(:,2)-colorMap(:,3))
