@@ -10,11 +10,11 @@
 %%  row           index of row
 %%  column        index of column
 %%  epsFileName   name of eps-file
-% written by Stefan Mueller stefan.mueller@fgan.de 1997
+% written by Stefan Mueller stefan.mueller@fgan.de (C) 2003
 
 function esubeps(nRows,nColumns,row,column,epsFileName)
   if nargin~=5
-    usage('esubeps(nRows,nColumns,row,column,epsFileName)');
+    eusage('esubeps(nRows,nColumns,row,column,epsFileName)');
   end
   eglobpar;
   tWidth=eWinWidth/nColumns;
