@@ -11,11 +11,11 @@
 %%  scaleX        scale factor in x-direction
 %%  scaleY        scale factor in y-direction
 %%  rotation      rotate symbol (deg)
-% written by Stefan Mueller stefan.mueller@fgan.de 1997
+% written by Stefan Mueller stefan.mueller@fgan.de (C) 2003
 
 function esymbol(xPos,yPos,symbolName,scaleX,scaleY,rotation)
   if nargin<3 |nargin>6
-    usage('esymbol(xPos,yPos,symbolName,[,scaleX[,scaleY[,rotation]]])');
+    eusage('esymbol(xPos,yPos,symbolName,[,scaleX[,scaleY[,rotation]]])');
   end
   if nargin<6
     rotation=0;
