@@ -11,8 +11,10 @@
 %%                the last text in the same line
 %%  y             y of start position
 %%                if x=0 then y is a relativ position to the current line 
-%%  fontSize      size of current font
-%%  alignment     1=left, 0=center, -1=right
+%%  fontSize      scalar size of current font
+%%                or vector [xSize ySize obliqueAngle(in deg)] of current font
+%%  alignment     1=right 0=center -1=left from x-positon, y = line position 
+%%                2=right 3=center 4=left from x-positon, y = height of text/2 
 %%  font          font number (definition in einit.m)
 %%  rotation      rotation of text (in deg)
 %%  color         color of text, [r g b] vector 
@@ -23,11 +25,11 @@
 %%  eTextFont
 %%  eTextAlignment
 %%  eTextFontSize
-% written by Stefan Mueller stefan.mueller@fgan.de 1997
+% written by Stefan Mueller stefan.mueller@fgan.de (C) 2003
 
 function etext(text,x,y,fontSize,alignment,font,rotation,color)
   if nargin<1 | nargin>8
-    usage ('etext(text[,x[,y[,fontSize[,alignment[,font[,rotation[,color]]]]]]])');
+    eusage('etext(text[,x[,y[,fontSize[,alignment[,font[,rotation[,color]]]]]]])');
   end
   eglobpar;
   if nargin<8
@@ -49,6 +51,11 @@ function etext(text,x,y,fontSize,alignment,font,rotation,color)
     x=0;
     y=0;
   end
+  if length(fontSize)==3
+    fontSize=[fontSize(1:2)*eFac fontSize(3)];
+  else
+    fontSize=fontSize*eFac;
+  end
   etextxy(eFile,...
           x*eFac,y*eFac,rotation,alignment,text,eFonts(font,:),...
-          fontSize*eFac,color); 
+          fontSize,color); 
