@@ -1,12 +1,12 @@
 %ticDistance=eticdis ( axesLength,maxTics)
 % compute tic distance for axes
-% written by Stefan Mueller stefan.mueller@fgan.de 1997
+% written by Stefan Mueller stefan.mueller@fgan.de (C) 2003
 
 function ticDistance=eticdis(axesLength,maxTics)
 
   % test parameter
   if (nargin~=2)
-    usage ('ticDistance=eticdis ( axesLength,maxTics)');
+    eusage('ticDistance=eticdis(axesLength,maxTics)');
   end
   if maxTics<2
     maxTics=2;
