@@ -9,10 +9,10 @@
 %%                 default: string of global parameter 'eFileName' 
 %%GLOBAL PARAMETER(S)
 %%  eFileName
-%written by stefan.mueller stefan.mueller@fgan.de 1997
+% written by stefan.mueller stefan.mueller@fgan.de (C) 2003
 function eview(epsFileName)
   if nargin>1
-    usage('eview([epsFileName])');
+    eusage('eview([epsFileName])');
   end
   eglobpar;
   if nargin<1
@@ -22,9 +22,13 @@ function eview(epsFileName)
     einit;
     eglobpar;
   end
-  gsview=sprintf('%s %s &',eGhostview,epsFileName);
-  if exist('matlabpath')~=5
-    system(gsview);
+  if isempty(eGhostview)
+    disp('error in eview: no Postscript viewer installed');
   else
-    unix(gsview);
+    gsview=sprintf('%s %s &',eGhostview,epsFileName);
+    if exist('matlabpath')~=5
+      system(gsview);
+    else
+      unix(gsview);
+    end
   end
