@@ -1,9 +1,9 @@
 %exyplots( epsFile,x,y,xData,yData,dash,color)
-% written by Stefan Mueller stefan.mueller@fgan.de 1997
+% written by Stefan Mueller stefan.mueller@fgan.de (C) 2003
 
 function exyplots( epsFile,x,y,xData,yData,xScale,yScale,angle,dash,color)
   if (nargin~=10)
-    usage ('exyplot ( epsFile,x,y,xData,yData,xScale,yScale,angle,dash,color)');
+    eusage('exyplots(epsFile,x,y,xData,yData,xScale,yScale,angle,dash,color)');
   end
   [rows colums]=size(xData);
   if rows==1
